@@ -1,4 +1,5 @@
 OFFER_ID = "OfferID"
+TS_DIALOGUE_ID = "TSDialogueID"
 
 OFFER_AUTHOR_ID = "UserID"
 AUTHOR_ID = "AuthorUserID"
@@ -6,6 +7,9 @@ AUTHOR_ID = "AuthorUserID"
 OFFER_QUOTA = "OfferQuota"
 AUTHOR_QUOTA = "AuthorQuota"
 
+QUOTA_APPROACHED_NOTIFICATION_SENT = "NotificationQuotaApproachedSent"
+QUOTA_EXHAUSTED_NOTIFICATION_SENT = "NotificationQuotaExhaustedSent"
+
 NUM_CALLS = "NumCalls"
 CALLS_LAST_PERIOD = "CallsLastPeriod"
 ROW_KEY = "RowKey"
